Transition

Function Transition 

pub fn Transition(_: TransitionProps) -> Element
This is a dioxus component similar to Vue’s <Transition> component.

It allows you to animate elements when they are added or removed from the DOM.

Props

For details, see the props struct definition.

  • children : Element

    The tree of elements to conduct the animation on.

  • id : ReadSignal<String>

    The id of the element within the tree to animate.

  • kind : ReadSignal<String>

    The kind of animation to conduct, you can either use one of the built-in transitions or create your own.

    Built-in transitions are enabled and injected by default, you can opt out by setting the default-features = false in your Cargo.toml.

  • duration : u32

    The duration of the animation in milliseconds.

  • ignore_first : bool

    Whether to ignore the fade-in part of the animation on the first run. Useful if the animated element is present by default.